@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
     as_is => [qw/get_options/],
 );
 
-our $VERSION = version->new('0.3.8');
+our $VERSION = version->new('0.3.9');
 our $EXIT    = 1;
 
 has options => (
@@ -73,19 +73,14 @@ has helper => (
     is      => 'rw',
     isa     => 'Bool',
 );
-has cmds => (
-    is      => 'rw',
-    isa     => 'ArrayRef[Getopt::Alt::Command]',
-    default => sub { [] },
-);
 has cmd => (
     is      => 'rw',
     isa     => 'Str',
     clearer => 'clear_cmd',
+    documentation => 'The found sub-command',
 );
 has sub_command => (
     is            => 'rw',
-    #isa           => 'Bool | HashRef[ArrayRef] | CodeRef',
     predicate     => 'has_sub_command',
     documentation => <<'DOC',
 if true (== 1) processing of args stops at first non-defined parameter, if
@@ -515,7 +510,7 @@ Getopt::Alt - Command line option passing with with lots of features
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt version 0.3.8.
+This documentation refers to Getopt::Alt version 0.3.9.
 
 =head1 SYNOPSIS
 
@@ -735,12 +730,6 @@ it's the callers package.
 
 Used when displaying --version info
 
-=item C<cmds> - ArrayRef[Getopt::Alt::Command]
-
-If the Getopt::Alt is being used as part of a package where individual
-commands have their own modules this parameter stores an instance of each
-commands. (Not yet fully implemented.
-
 =item C<options> - Str (Default Getopt::Alt::Dynamic)
 
 The parent class for generating options.
